@@ -1,11 +1,11 @@
 #ifndef FASTREAD_PROGRESS_H_
 #define FASTREAD_PROGRESS_H_
 
+#include <Rcpp.h>
+#include <sstream>
 #include <time.h>
 
-inline int now() {
-  return clock() / CLOCKS_PER_SEC;
-}
+inline int now() { return clock() / CLOCKS_PER_SEC; }
 
 inline std::string clearLine(int width = 50) {
   return "\r" + std::string(' ', width) + "\r";
@@ -26,16 +26,13 @@ class Progress {
   bool show_, stopped_;
 
 public:
-
-  Progress(int min = 5, int width = 80):
-    timeMin_(min),
-    timeInit_(now()),
-    timeStop_(now()),
-    width_(width),
-    show_(false),
-    stopped_(false)
-  {
-  }
+  Progress(int min = 5, int width = Rf_GetOptionWidth())
+      : timeMin_(min),
+        timeInit_(now()),
+        timeStop_(now()),
+        width_(width),
+        show_(false),
+        stopped_(false) {}
 
   void stop() {
     timeStop_ = now();
@@ -54,16 +51,22 @@ public:
       }
     }
 
-    // double time_left = (1 - prop) * est;
-    int nbars = prop * width_, nspaces = (1 - prop) * width_;
-
-    std::string bars(nbars, '='), spaces(nspaces, ' ');
-    tfm::format(Rcpp::Rcout, "\r|%s%s| %3d%%", bars, spaces, (int) (prop * 100));
+    std::stringstream labelStream;
+    tfm::format(labelStream, " %3d%%", (int)(prop * 100));
     if (size > 0) {
-      tfm::format(Rcpp::Rcout, " %4.0f MB", size);
-    } else {
-      tfm::format(Rcpp::Rcout, "           ");
+      tfm::format(labelStream, " %4.0f MB", size);
     }
+
+    std::string label = labelStream.str();
+
+    int barSize = width_ - label.size() - 2;
+    if (barSize < 0) {
+      return;
+    }
+    int nbars = prop * barSize;
+    int nspaces = (1 - prop) * barSize;
+    std::string bars(nbars, '='), spaces(nspaces, ' ');
+    Rcpp::Rcout << '\r' << '|' << bars << spaces << '|' << label;
   }
 
   ~Progress() {
@@ -75,9 +78,9 @@ public:
         timeStop_ = now();
       Rcpp::Rcout << "\n";
 
-    } catch (...) {}
+    } catch (...) {
+    }
   }
-
 };
 
 #endif
