@@ -1,19 +1,21 @@
 #ifndef FASTREAD_TOKENIZERLINE_H_
 #define FASTREAD_TOKENIZERLINE_H_
 
-#include <Rcpp.h>
 #include "Token.h"
 #include "Tokenizer.h"
 #include "utils.h"
+#include <Rcpp.h>
 
 class TokenizerLine : public Tokenizer {
   SourceIterator begin_, cur_, end_;
+  std::vector<std::string> NA_;
   bool moreTokens_;
   int line_;
 
 public:
+  TokenizerLine(std::vector<std::string> NA) : NA_(NA), moreTokens_(false) {}
 
-  TokenizerLine(): moreTokens_(false) {}
+  TokenizerLine() : moreTokens_(false) {}
 
   void tokenize(SourceIterator begin, SourceIterator end) {
     begin_ = begin;
@@ -23,9 +25,9 @@ public:
     moreTokens_ = true;
   }
 
-  std::pair<double,size_t> progress() {
+  std::pair<double, size_t> progress() {
     size_t bytes = cur_ - begin_;
-    return std::make_pair(bytes / (double) (end_ - begin_), bytes);
+    return std::make_pair(bytes / (double)(end_ - begin_), bytes);
   }
 
   Token nextToken() {
@@ -45,10 +47,14 @@ public:
       if ((line_ + 1) % 500000 == 0)
         Rcpp::checkUserInterrupt();
 
-      switch(*cur_) {
+      switch (*cur_) {
       case '\r':
-      case '\n':
-        return Token(token_begin, advanceForLF(&cur_, end_), hasNull, line_++, 0);
+      case '\n': {
+        Token t =
+            Token(token_begin, advanceForLF(&cur_, end_), line_++, 0, hasNull);
+        t.flagNA(NA_);
+        return t;
+      }
       default:
         break;
       }
@@ -59,10 +65,11 @@ public:
     if (token_begin == end_) {
       return Token(TOKEN_EOF, line_++, 0);
     } else {
-      return Token(token_begin, end_, hasNull, line_++, 0);
+      Token t = Token(token_begin, end_, line_++, 0, hasNull);
+      t.flagNA(NA_);
+      return t;
     }
   }
-
 };
 
 #endif
